QueryType enum

Inheritance
Available extensions

Values

where → const QueryType
whereIsNotEqualTo → const QueryType
whereArrayContains → const QueryType
whereArrayContainsAny → const QueryType
whereGreaterThan → const QueryType
whereGreaterThanOrEqual → const QueryType
whereLessThan → const QueryType
whereLessThanOrEqual → const QueryType
whereIn → const QueryType
orderBy → const QueryType
ascendingOrder → const QueryType
descendingOrder → const QueryType
limit → const QueryType
startAt → const QueryType
startAfter → const QueryType
endAt → const QueryType
endBefore → const QueryType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueryType>
A constant List of the values in this enum, in order of their declaration.